netapp_ontap.models.data_engine_governance_policies_guardrail_issue_tags API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_engine_governance_policies_guardrail_issue_tags`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataEngineGovernancePoliciesGuardrailIssueTagsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataEngineGovernancePoliciesGuardrailIssueTags object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `classification_type: str GET`

    Type of the tag. Possible values are:

    - data_classifier: Data classifier tag.
    - document_classifier: Document classifier tag.
    - data_classifier_category: Data classifier category tag.
    - document_classifier_category: Document classifier category tag.

    Valid choices:

    - data_classifier
    - document_classifier
    - data_classifier_category
    - document_classifier_category
  `tag: str GET`

    Tag of the classifier or category.

    Example: CLS_ENTD00000